/* 
 * Copyright (c) 2012, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * */

/*
 * ======== PROLOGUE ========
 */

#ifndef ti_uia_runtime_EventHdr__include
#define ti_uia_runtime_EventHdr__include

#ifndef __nested__
#define __nested__
#define ti_uia_runtime_EventHdr__top__
#endif

#ifdef __cplusplus
#define __extern extern "C"
#else
#define __extern extern
#endif

#define ti_uia_runtime_EventHdr___VERS 150


/*
 * ======== INCLUDES ========
 */

#include <xdc/std.h>

#include <xdc/runtime/xdc.h>
//#include <xdc/runtime/Types.h>
#include <ti/uia/runtime/EventHdr__prologue.h>
//#include <ti/uia/runtime/package/package.defs.h>

//#include <xdc/runtime/IModule.h>


/*
 * ======== AUXILIARY DEFINITIONS ========
 */

/* HdrType: the header format to be used when logging an event
 *
 *  Each event's first word includes the type, length of the event and 
 *  sequence number. The length includes the first word and is in bytes.
 *  
 *  The following is the desciption of the first word.
 *
 *  @p(code) 
 *  EventHdr
 *   3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0
 *   1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
 *  |---------------------------------------------------------------|
 *  |H H H H H|L L L L L L L L L L L|S S S S S S S S S S S S S S S S|
 *  |---------------------------------------------------------------|
 *
 *  H = HdrType         (5-bits)
 *  L = Event Length    (11-bits)
 *  S = Sequence Number (16-bits)
 *  @p
 * 
 *  There are currently 4 different types of events supported in UIA. The 
 *  following discusses the format of each one of the types. 
 * 
 *  @p(code) 
 *  HdrType_Event
 *    word0: EventHdr
 *    word1: event Id (top 16 bits) & module Id (bottom 16 bits)
 *
 *  HdrType_EventWithTimestamp
 *    word0: EventHdr
 *    word1: Timestamp lower 32 bits
 *    word2: Timestamp upper 32 bits
 *    word3: event Id (top 16 bits) & module Id (bottom 16 bits)
 *
 *  HdrType_EventWithSnapshotId
 *    word0: EventHdr
 *    word1: event Id (top 16 bits) & module Id (bottom 16 bits)
 *    word2: filename pointer
 *    word3: linenum
 *    word4: snapshotId
 *    word5: address where the data was located
 *    word6: total length of data (top 16-bits)
 *           length for this record (bottom 16 bits)
 *    word7: format pointer
 *    data:  the rest of the record contains the data
 *
 *  HdrType_EventWithSnapshotIdAndTimestamp: 
 *    word0: EventHdr
 *    word1: Timestamp lower 32 bits
 *    word2: Timestamp upper 32 bits
 *    word3: event Id (top 16 bits) & module Id (bottom 16 bits)
 *    word4: filename pointer
 *    word5: linenum
 *    word6: snapshotId
 *    word7: address where the data was located
 *    word8: total length of data (top 16-bits)
 *           length for this record (bottom 16 bits)
 *    word9: format pointer
 *    data:  the rest of the record contains the data
 *
 *  Snapshot events can span multiple records. The snapshotId is used to
 *  correlate the records when this occurs.
 *  The length field (word6 or word8) contains two lengths. The bottom 16 bits
 *  length of data for this record. The top 16 bits is the sum of all 
 *  lengths for this specific snapshotId. 
 *
 *  The address field points to the location of the data. When the snapshot
 *  spans multiple records, the address field is updated accordingly. Therefore
 *  this field can be used to detect dropped records. Note the snapshot
 *  event data is contiguous.
 *  @p
 *  For shared, non-packetized event transports that carry events from
 *  multiple cores, or for events logged by applications runnning on 
 *  multiprocess O/Ses, the event header needs to identify which endpoint ID the
 *  event was logged from and which process Id logged the event.
 *  The following two additional event headers support these situations.
 *
 *  HdrType_EventWithTimestampAndEndpointId 
 *    word0: EventHdr
 *    word1: Timestamp lower 32 bits
 *    word2: Timestamp upper 32 bits
 *    word3: EndpointId (lower 16 bits)
 *    word4: ProcessId
 *    word3: event Id (top 16 bits) & module Id (bottom 16 bits)
 * 
 *  HdrType_EventWithSnapshotIdAndTimestampAndEndpointId: 
 *    word0: EventHdr
 *    word1: Timestamp lower 32 bits
 *    word2: Timestamp upper 32 bits
 *    word3: EndpointId (lower 16 bits)
 *    word4: ProcessId
 *    word5: event Id (top 16 bits) & module Id (bottom 16 bits)
 *    word6: filename pointer
 *    word7: linenum
 *    word8: snapshotId
 *    word9: address where the data was located
 *    word10: total length of data (top 16-bits)
 *           length for this record (bottom 16 bits)
 *    word11: format pointer
 *    data:  the rest of the record contains the data
 * 
 */
enum ti_uia_runtime_EventHdr_HdrType {
    ti_uia_runtime_EventHdr_HdrType_Event = 0,
    ti_uia_runtime_EventHdr_HdrType_EventWithTimestamp = 1,
    ti_uia_runtime_EventHdr_HdrType_EventWithSnapshotId = 2,
    ti_uia_runtime_EventHdr_HdrType_EventWithSnapshotIdAndTimestamp = 3,
    ti_uia_runtime_EventHdr_HdrType_Reserved4 = 4,
    ti_uia_runtime_EventHdr_HdrType_EventWithTimestampAndEndpointId = 5,
    ti_uia_runtime_EventHdr_HdrType_Reserved6 = 6,
    ti_uia_runtime_EventHdr_HdrType_EventWithSnapshotIdAndTimestampAndEndpointId = 7,
    ti_uia_runtime_EventHdr_HdrType_Reserved8 = 8,
    ti_uia_runtime_EventHdr_HdrType_Reserved9 = 9,
    ti_uia_runtime_EventHdr_HdrType_Reserved10 = 10,
    ti_uia_runtime_EventHdr_HdrType_Reserved11 = 11,
    ti_uia_runtime_EventHdr_HdrType_Reserved12 = 12,
    ti_uia_runtime_EventHdr_HdrType_Reserved13 = 13,
    ti_uia_runtime_EventHdr_HdrType_Reserved14 = 14,
    ti_uia_runtime_EventHdr_HdrType_Reserved15 = 15,
    ti_uia_runtime_EventHdr_HdrType_Reserved16 = 16,
    ti_uia_runtime_EventHdr_HdrType_Reserved17 = 17,
    ti_uia_runtime_EventHdr_HdrType_Reserved18 = 18,
    ti_uia_runtime_EventHdr_HdrType_Reserved19 = 19,
    ti_uia_runtime_EventHdr_HdrType_Reserved20 = 20,
    ti_uia_runtime_EventHdr_HdrType_Reserved21 = 21,
    ti_uia_runtime_EventHdr_HdrType_Reserved22 = 22,
    ti_uia_runtime_EventHdr_HdrType_Reserved23 = 23,
    ti_uia_runtime_EventHdr_HdrType_Reserved24 = 24,
    ti_uia_runtime_EventHdr_HdrType_Reserved25 = 25,
    ti_uia_runtime_EventHdr_HdrType_Reserved26 = 26,
    ti_uia_runtime_EventHdr_HdrType_Reserved27 = 27,
    ti_uia_runtime_EventHdr_HdrType_Reserved28 = 28,
    ti_uia_runtime_EventHdr_HdrType_Reserved29 = 29,
    ti_uia_runtime_EventHdr_HdrType_Reserved30 = 30,
    ti_uia_runtime_EventHdr_HdrType_Reserved31 = 31
};
typedef enum ti_uia_runtime_EventHdr_HdrType ti_uia_runtime_EventHdr_HdrType;


/*
 * ======== INTERNAL DEFINITIONS ========
 */


/*
 * ======== MODULE-WIDE CONFIGS ========
 */


/*
 * ======== FUNCTION DECLARATIONS ========
 */

/*
 * ======== SYSTEM FUNCTIONS ========
 */


/*
 * ======== EPILOGUE ========
 */

#include <ti/uia/runtime/EventHdr__epilogue.h>

#ifdef ti_uia_runtime_EventHdr__top__
#undef __nested__
#endif

#endif /* ti_uia_runtime_EventHdr__include */


/*
 * ======== STATE STRUCTURES ========
 */

/*
 * ======== PREFIX ALIASES ========
 */

#if !defined(__nested__) && !defined(ti_uia_runtime_EventHdr__nolocalnames)

#ifndef ti_uia_runtime_EventHdr__localnames__done
#define ti_uia_runtime_EventHdr__localnames__done

/* module prefix */
#define EventHdr_HdrType ti_uia_runtime_EventHdr_HdrType
#define EventHdr_HdrType_Event ti_uia_runtime_EventHdr_HdrType_Event
#define EventHdr_HdrType_EventWithTimestamp ti_uia_runtime_EventHdr_HdrType_EventWithTimestamp
#define EventHdr_HdrType_EventWithSnapshotId ti_uia_runtime_EventHdr_HdrType_EventWithSnapshotId
#define EventHdr_HdrType_EventWithSnapshotIdAndTimestamp ti_uia_runtime_EventHdr_HdrType_EventWithSnapshotIdAndTimestamp
#define EventHdr_HdrType_Reserved4 ti_uia_runtime_EventHdr_HdrType_Reserved4
#define EventHdr_HdrType_EventWithTimestampAndEndpointId ti_uia_runtime_EventHdr_HdrType_EventWithTimestampAndEndpointId
#define EventHdr_HdrType_Reserved6 ti_uia_runtime_EventHdr_HdrType_Reserved6
#define EventHdr_HdrType_EventWithSnapshotIdAndTimestampAndEndpointId ti_uia_runtime_EventHdr_HdrType_EventWithSnapshotIdAndTimestampAndEndpointId
#define EventHdr_HdrType_Reserved8 ti_uia_runtime_EventHdr_HdrType_Reserved8
#define EventHdr_HdrType_Reserved9 ti_uia_runtime_EventHdr_HdrType_Reserved9
#define EventHdr_HdrType_Reserved10 ti_uia_runtime_EventHdr_HdrType_Reserved10
#define EventHdr_HdrType_Reserved11 ti_uia_runtime_EventHdr_HdrType_Reserved11
#define EventHdr_HdrType_Reserved12 ti_uia_runtime_EventHdr_HdrType_Reserved12
#define EventHdr_HdrType_Reserved13 ti_uia_runtime_EventHdr_HdrType_Reserved13
#define EventHdr_HdrType_Reserved14 ti_uia_runtime_EventHdr_HdrType_Reserved14
#define EventHdr_HdrType_Reserved15 ti_uia_runtime_EventHdr_HdrType_Reserved15
#define EventHdr_HdrType_Reserved16 ti_uia_runtime_EventHdr_HdrType_Reserved16
#define EventHdr_HdrType_Reserved17 ti_uia_runtime_EventHdr_HdrType_Reserved17
#define EventHdr_HdrType_Reserved18 ti_uia_runtime_EventHdr_HdrType_Reserved18
#define EventHdr_HdrType_Reserved19 ti_uia_runtime_EventHdr_HdrType_Reserved19
#define EventHdr_HdrType_Reserved20 ti_uia_runtime_EventHdr_HdrType_Reserved20
#define EventHdr_HdrType_Reserved21 ti_uia_runtime_EventHdr_HdrType_Reserved21
#define EventHdr_HdrType_Reserved22 ti_uia_runtime_EventHdr_HdrType_Reserved22
#define EventHdr_HdrType_Reserved23 ti_uia_runtime_EventHdr_HdrType_Reserved23
#define EventHdr_HdrType_Reserved24 ti_uia_runtime_EventHdr_HdrType_Reserved24
#define EventHdr_HdrType_Reserved25 ti_uia_runtime_EventHdr_HdrType_Reserved25
#define EventHdr_HdrType_Reserved26 ti_uia_runtime_EventHdr_HdrType_Reserved26
#define EventHdr_HdrType_Reserved27 ti_uia_runtime_EventHdr_HdrType_Reserved27
#define EventHdr_HdrType_Reserved28 ti_uia_runtime_EventHdr_HdrType_Reserved28
#define EventHdr_HdrType_Reserved29 ti_uia_runtime_EventHdr_HdrType_Reserved29
#define EventHdr_HdrType_Reserved30 ti_uia_runtime_EventHdr_HdrType_Reserved30
#define EventHdr_HdrType_Reserved31 ti_uia_runtime_EventHdr_HdrType_Reserved31
#define EventHdr_getHdrType ti_uia_runtime_EventHdr_getHdrType
#define EventHdr_setHdrType ti_uia_runtime_EventHdr_setHdrType
#define EventHdr_getLength ti_uia_runtime_EventHdr_getLength
#define EventHdr_setLength ti_uia_runtime_EventHdr_setLength
#define EventHdr_getSeqCount ti_uia_runtime_EventHdr_getSeqCount
#define EventHdr_setSeqCount ti_uia_runtime_EventHdr_setSeqCount
#define EventHdr_genEventHdrWord1 ti_uia_runtime_EventHdr_genEventHdrWord1
/*
#define EventHdr_Module_name ti_uia_runtime_EventHdr_Module_name
#define EventHdr_Module_id ti_uia_runtime_EventHdr_Module_id
#define EventHdr_Module_startup ti_uia_runtime_EventHdr_Module_startup
#define EventHdr_Module_startupDone ti_uia_runtime_EventHdr_Module_startupDone
#define EventHdr_Module_hasMask ti_uia_runtime_EventHdr_Module_hasMask
#define EventHdr_Module_getMask ti_uia_runtime_EventHdr_Module_getMask
#define EventHdr_Module_setMask ti_uia_runtime_EventHdr_Module_setMask
#define EventHdr_Object_heap ti_uia_runtime_EventHdr_Object_heap
#define EventHdr_Module_heap ti_uia_runtime_EventHdr_Module_heap
*/

#define EventHdr_Hdr ti_uia_runtime_EventHdr_Hdr
#define EventHdr_isASnapshotEvent ti_uia_runtime_EventHdr_isASnapshotEvent
#define EventHdr_getSnapshotId ti_uia_runtime_EventHdr_getSnapshotId
#define EventHdr_getSnapshotData ti_uia_runtime_EventHdr_getSnapshotData
#define EventHdr_getSnapshotFmtStringAdrs ti_uia_runtime_EventHdr_getSnapshotFmtStringAdrs
#define EventHdr_getSnapshotDataAdrs ti_uia_runtime_EventHdr_getSnapshotDataAdrs
#define EventHdr_getSnapshotEventDataLength ti_uia_runtime_EventHdr_getSnapshotEventDataLength
#define EventHdr_getSnapshotTotalLength ti_uia_runtime_EventHdr_getSnapshotTotalLength
#define EventHdr_sizeOfEventHeader_EventWithSnapshotIdAndTimestamp ti_uia_runtime_EventHdr_sizeOfEventHeader_EventWithSnapshotIdAndTimestamp

#endif /* ti_uia_runtime_EventHdr__localnames__done */
#endif
